@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import sys
 from dataclasses import dataclass
 from functools import partial
 from typing import Callable
@@ -56,10 +55,13 @@ class SSIM(Scaler):
     smooth: float | VSFunction = ((3 ** 2 - 1) / 12) ** 0.5
     curve: Transfer | bool = False
     sigmoid: bool = False
+    epsilon: float = 1e-6
     scaler: Scaler = Catrom()
 
     def scale(self, clip: vs.VideoNode, width: int, height: int, shift: tuple[float, float] = (0, 0)) -> vs.VideoNode:
-        return ssim_downsample(clip, width, height, self.smooth, self.scaler, self.curve, self.sigmoid, shift)
+        return ssim_downsample(
+            clip, width, height, self.smooth, self.scaler, self.curve, self.sigmoid, shift, self.epsilon
+        )
 
 
 def ssim_downsample(
@@ -67,7 +69,7 @@ def ssim_downsample(
     smooth: float | VSFunction = ((3 ** 2 - 1) / 12) ** 0.5,
     scaler: Scaler | str = Catrom(),
     curve: Transfer | bool = False, sigmoid: bool = False,
-    shift: tuple[float, float] = (0, 0)
+    shift: tuple[float, float] = (0, 0), epsilon: float = 1e-6
 ) -> vs.VideoNode:
     """
     SSIM downsampler is an image downscaling technique that aims to optimize
@@ -108,8 +110,6 @@ def ssim_downsample(
     """
     assert clip.format
 
-    epsilon = sys.float_info.epsilon
-
     if isinstance(scaler, str):
         scaler = get_kernel(scaler)()
     elif isinstance(scaler, SSIM):
@@ -134,7 +134,7 @@ def ssim_downsample(
 
     l1 = scaler.scale(clip, width, height, shift)
 
-    l1_sq, c_sq = [x.akarin.Expr('x dup *') for x in (l1, clip)]
+    l1_sq, c_sq = [expr_func(x, 'x dup *') for x in (l1, clip)]
 
     l2 = scaler.scale(c_sq, width, height, shift)
 
